@@ -157,13 +157,12 @@ def process_party_elements(inel, outel):
         namespaces=_NSMAP
     ):
         security_details_id = v2_security_details.get(cppa2('securityId'))
-        logging.error('!!!!!!!!!! {}'.format(security_details_id))
         for v2_ta in v2_security_details.xpath(
             'cppa2:TrustAnchors',
             namespaces=_NSMAP
         ):
             v3_ta = lxml.etree.SubElement(outel,
-                                          cppa3('TrustAnchor'),
+                                          cppa3('TrustAnchorSet'),
                                           id=security_details_id)
             for v2_acert_ref in v2_ta.xpath(
                 'cppa2:AnchorCertificateRef',
@@ -173,11 +172,6 @@ def process_party_elements(inel, outel):
                                       cppa3('AnchorCertificateRef'),
                                       certId=v2_acert_ref.get(cppa2('certId')))
 
-
-#def process_x509(inel, outel):
-
-
-
 def match_collaborationroles(party_info, counterparty_info, parent,
                              matched_channels, matched_transports,
                              matched_payload_profiles, mode):
