@@ -77,6 +77,9 @@ class CPPA3TestCase( unittest.TestCase ):
 
             if self.schema.validate(acpp) and self.schema.validate(bcpp):
                 logging.info('CPP A and B are valid for {}'.format(id))
+        else:
+            logging.info('Not validating {} against CPPA3 schema'.format(id))
+
 
         cpa = unify(acpp, bcpp, agreementid=agreementid,
                     requested_activation_date=requested_activation_date,
@@ -436,11 +439,60 @@ class CPPA3TestCase( unittest.TestCase ):
         self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '0314')
 
 
+    # Only a Trust Anchor, no Signing cert - Send.
+    def test_0315(self):
+        self.do_unification('0315')
+
+
+
     # XKMS
     def test_0320(self):
         self.do_unification('0320')
 
 
+    # Certificate Requirements
+    # A Signing Certificate is explicitly required and presented
+    def test_0330(self):
+        self.do_unification('0330')
+
+    # A Signing Certificate is explicitly not required and still presented
+    def test_0331(self):
+        self.do_unification('0331')
+
+    # A Signing Certificate is explicitly required but not presented
+    def test_0332(self):
+        self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '0332')
+
+    # An encryption Certificate is explicitly required and presented
+    def test_0335(self):
+        self.do_unification('0335')
+
+    # An encryption Certificate is explicitly not required and still presented
+    def test_0336(self):
+        self.do_unification('0336')
+
+    # An encryption Certificate is explicitly required and not presented
+    def test_0337(self):
+        self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '0337')
+
+    # An TLS server Certificate is explicitly required and presented
+    def test_0340(self):
+        self.do_unification('0340')
+
+    # A TLS server Certificate is explicitly required and not presented
+    def test_0342(self):
+        self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '0342')
+
+    # An TLS client Certificate is explicitly required and presented
+    def test_0345(self):
+        self.do_unification('0345')
+
+    # A TLS client Certificate is explicitly required and not presented
+    def test_0347(self):
+        self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '0347')
+
+
+
     """
     0400 TLS tests
     """
